package plugins;
use Exporter;
use Time::Local;
use RRDs;

@ISA = qw(Exporter);


@EXPORT = qw(init_plugins obtain_info create_rrd update_rrd );


sub init_plugins {
  my %conf;

  # default for CPU
  $conf{"CPU"}{"FIXED"}=2;
  $conf{"CPU"}{"DATA"}="GAUGE";
  $conf{"CPU"}{"LABLE"}="CPU of Host";
  $conf{"CPU"}{"U_EXPONENT"}=0;
  $conf{"CPU"}{"FORMAT"}="%6.2lf%%";
  $conf{"CPU"}{"L_LIMIT"}=0;

  # CPU for win32 machines
  $conf{"CPU.WIN"}{"FIXED"}=1;
  $conf{"CPU.WIN"}{"DATA"}="GAUGE";
  $conf{"CPU.WIN"}{"LABLE"}="CPU of Host";
  $conf{"CPU.WIN"}{"V_LABLE"}="%";
  $conf{"CPU.WIN"}{"U_EXPONENT"}=0;
  $conf{"CPU.WIN"}{"FORMAT"}="%6.2lf%%";
  $conf{"CPU.WIN"}{"L_LIMIT"}=0;
  $conf{"CPU.WIN"}{"U_LIMIT"}=100;

  # default for MEM 
  $conf{"MEM"}{"FIXED"}=2;
  $conf{"MEM"}{"DATA"}="GAUGE";
  $conf{"MEM"}{"LABLE"}="Memory of Host";
  $conf{"MEM"}{"V_LABLE"}="%";
  $conf{"MEM"}{"U_EXPONENT"}=0;
  $conf{"MEM"}{"FORMAT"}="%6.2lf%%";
  $conf{"MEM"}{"L_LIMIT"}=0;
  $conf{"MEM"}{"U_LIMIT"}=100;

  # default for PROC
  $conf{"PROC"}{"FIXED"}=0;
  $conf{"PROC"}{"DATA"}="GAUGE";
  $conf{"PROC"}{"LABLE"}="Processes of Host";
  $conf{"PROC"}{"U_EXPONENT"}=0;
  $conf{"PROC"}{"FORMAT"}="%6.0lf";
  $conf{"PROC"}{"L_LIMIT"}=0;

  # default for NETB
  $conf{"NETB"}{"FIXED"}=0;
  $conf{"NETB"}{"DATA"}="COUNTER";
  $conf{"NETB"}{"LABLE"}="Network of Host";
  $conf{"NETB"}{"V_LABLE"}="bits/s";
  $conf{"NETB"}{"L_MODIFY"}="1000,/";
  $conf{"NETB"}{"FORMAT"}="%6.0lf k";
  $conf{"NETB"}{"L_LIMIT"}=0;

  # default for NETI
  $conf{"NETI"}{"FIXED"}=8;
  $conf{"NETI"}{"DATA"}="COUNTER";
  $conf{"NETI"}{"LABLE"}="Interface of Host";
  $conf{"NETI"}{"V_LABLE"}="packets/s";
  $conf{"NETI"}{"FORMAT"}="%6.0lf";
  $conf{"NETI"}{"L_LIMIT"}=0;
  #  NETI for FREEBSD
  $conf{"NETI.FREEBSD"}{"FIXED"}=6;
  $conf{"NETI.FREEBSD"}{"DATA"}="COUNTER";
  $conf{"NETI.FREEBSD"}{"LABLE"}="Interface of Host";
  $conf{"NETI.FREEBSD"}{"V_LABLE"}="packets/s";
  $conf{"NETI.FREEBSD"}{"FORMAT"}="%6.0lf";
  $conf{"NETI.FREEBSD"}{"L_LIMIT"}=0;

  # default for DISK
  $conf{"DISK"}{"FIXED"}=0;
  $conf{"DISK"}{"DATA"}="GAUGE";
  $conf{"DISK"}{"LABLE"}="Disk of Host";
  $conf{"DISK"}{"V_LABLE"}="%";
  $conf{"DISK"}{"U_EXPONENT"}=0;
  $conf{"DISK"}{"FORMAT"}="%6.2lf%%";
  $conf{"DISK"}{"L_LIMIT"}=0;
  $conf{"DISK"}{"U_LIMIT"}=100;

  \%conf;
};

sub obtain_info {
  my %info;
  my @atemp;
  my ($home_dir,$host)=@_;
  if ( -f "$home_dir/data/$host/info2" ){
    open(FL,"$home_dir/data/$host/info2");
    @atemp=<FL>;close(FL);
    foreach $atmp (@atemp){
     chomp($atmp);
     ($lable,$value)=split(/\=/,$atmp);
     $info{$lable}=$value;
    }
  }
  \%info;
}


sub create_rrd {
  my ($file,$type,$number)=@_;
  my %atype;
  my $start=time();
  my $tmp;
  my @rrd_out;

  for($tmp=0;$tmp < $number;$tmp++){
    push @rrd_out,"DS:$tmp:$type:600:U:U";
  }

  RRDs::create ($file, "--start",$start-1, "--step",300,
              @rrd_out,
              "RRA:AVERAGE:0.5:1:600",
              "RRA:AVERAGE:0.5:6:700",
              "RRA:AVERAGE:0.5:24:775",
              "RRA:AVERAGE:0.5:288:797",
              "RRA:MAX:0.5:1:600 ",
              "RRA:MAX:0.5:6:700 ",
              "RRA:MAX:0.5:24:775",
              "RRA:MAX:0.5:288:797",
              "RRA:MIN:0.5:1:600 ",
              "RRA:MIN:0.5:6:700 ",
              "RRA:MIN:0.5:24:775",
              "RRA:MIN:0.5:288:797"
              );
}

sub update_rrd {
  my ($file,@values)=@_;
  my $start=time();
  my $tmp=join(":",@values);
  $tmp=~ s/^://gi;$tmp=~ s/:$//gi;
  RRDs::update $file, "$start:".$tmp;
}


1;
